pub struct Result(/* private fields */);Expand description
Implementations
Sourceimpl Result
impl Result
pub fn result(self) -> Result<(), Result>
pub fn result_with_success<T>(self, v: T) -> Result<T, Result>
pub unsafe fn assume_init_on_success<T>( self, v: MaybeUninit<T>, ) -> Result<T, Result>
Sourceimpl Result
impl Result
Sourcepub const EVENT_RESET: Result
pub const EVENT_RESET: Result
An event is unsignaled
Sourcepub const INCOMPLETE: Result
pub const INCOMPLETE: Result
A return array was too small for the result
Sourcepub const ERROR_OUT_OF_HOST_MEMORY: Result
pub const ERROR_OUT_OF_HOST_MEMORY: Result
A host memory allocation has failed
Sourcepub const ERROR_OUT_OF_DEVICE_MEMORY: Result
pub const ERROR_OUT_OF_DEVICE_MEMORY: Result
A device memory allocation has failed
Sourcepub const ERROR_INITIALIZATION_FAILED: Result
pub const ERROR_INITIALIZATION_FAILED: Result
Initialization of an object has failed
Sourcepub const ERROR_DEVICE_LOST: Result
pub const ERROR_DEVICE_LOST: Result
The logical device has been lost. See https://registry.khronos.org/vulkan/specs/1.3-extensions/html/vkspec.html#devsandqueues-lost-device
Sourcepub const ERROR_MEMORY_MAP_FAILED: Result
pub const ERROR_MEMORY_MAP_FAILED: Result
Mapping of a memory object has failed
Sourcepub const ERROR_LAYER_NOT_PRESENT: Result
pub const ERROR_LAYER_NOT_PRESENT: Result
Layer specified does not exist
Sourcepub const ERROR_EXTENSION_NOT_PRESENT: Result
pub const ERROR_EXTENSION_NOT_PRESENT: Result
Extension specified does not exist
Sourcepub const ERROR_FEATURE_NOT_PRESENT: Result
pub const ERROR_FEATURE_NOT_PRESENT: Result
Requested feature is not available on this device
Sourcepub const ERROR_INCOMPATIBLE_DRIVER: Result
pub const ERROR_INCOMPATIBLE_DRIVER: Result
Unable to find a Vulkan driver
Sourcepub const ERROR_TOO_MANY_OBJECTS: Result
pub const ERROR_TOO_MANY_OBJECTS: Result
Too many objects of the type have already been created
Sourcepub const ERROR_FORMAT_NOT_SUPPORTED: Result
pub const ERROR_FORMAT_NOT_SUPPORTED: Result
Requested format is not supported on this device
Sourcepub const ERROR_FRAGMENTED_POOL: Result
pub const ERROR_FRAGMENTED_POOL: Result
A requested pool allocation has failed due to fragmentation of the pool’s memory
Sourcepub const ERROR_UNKNOWN: Result
pub const ERROR_UNKNOWN: Result
An unknown error has occurred, due to an implementation or application bug
Sourceimpl Result
Generated from ‘VK_KHR_surface’
impl Result
Generated from ‘VK_KHR_surface’
pub const ERROR_SURFACE_LOST_KHR: Result
pub const ERROR_NATIVE_WINDOW_IN_USE_KHR: Result
Sourceimpl Result
Generated from ‘VK_KHR_swapchain’
impl Result
Generated from ‘VK_KHR_swapchain’
pub const SUBOPTIMAL_KHR: Result
pub const ERROR_OUT_OF_DATE_KHR: Result
Sourceimpl Result
Generated from ‘VK_KHR_display_swapchain’
impl Result
Generated from ‘VK_KHR_display_swapchain’
pub const ERROR_INCOMPATIBLE_DISPLAY_KHR: Result
Sourceimpl Result
Generated from ‘VK_EXT_debug_report’
impl Result
Generated from ‘VK_EXT_debug_report’
pub const ERROR_VALIDATION_FAILED_EXT: Result
Sourceimpl Result
Generated from ‘VK_NV_glsl_shader’
impl Result
Generated from ‘VK_NV_glsl_shader’
pub const ERROR_INVALID_SHADER_NV: Result
Sourceimpl Result
Generated from ‘VK_KHR_video_queue’
impl Result
Generated from ‘VK_KHR_video_queue’
pub const ERROR_IMAGE_USAGE_NOT_SUPPORTED_KHR: Result
pub const ERROR_VIDEO_PICTURE_LAYOUT_NOT_SUPPORTED_KHR: Result
pub const ERROR_VIDEO_PROFILE_OPERATION_NOT_SUPPORTED_KHR: Result
pub const ERROR_VIDEO_PROFILE_FORMAT_NOT_SUPPORTED_KHR: Result
pub const ERROR_VIDEO_PROFILE_CODEC_NOT_SUPPORTED_KHR: Result
pub const ERROR_VIDEO_STD_VERSION_NOT_SUPPORTED_KHR: Result
Sourceimpl Result
Generated from ‘VK_KHR_maintenance1’
impl Result
Generated from ‘VK_KHR_maintenance1’
pub const ERROR_OUT_OF_POOL_MEMORY_KHR: Result = Self::ERROR_OUT_OF_POOL_MEMORY
Sourceimpl Result
Generated from ‘VK_KHR_external_memory’
impl Result
Generated from ‘VK_KHR_external_memory’
pub const ERROR_INVALID_EXTERNAL_HANDLE_KHR: Result = Self::ERROR_INVALID_EXTERNAL_HANDLE
Sourceimpl Result
Generated from ‘VK_EXT_descriptor_indexing’
impl Result
Generated from ‘VK_EXT_descriptor_indexing’
pub const ERROR_FRAGMENTATION_EXT: Result = Self::ERROR_FRAGMENTATION
Sourceimpl Result
Generated from ‘VK_EXT_global_priority’
impl Result
Generated from ‘VK_EXT_global_priority’
pub const ERROR_NOT_PERMITTED_EXT: Result = Self::ERROR_NOT_PERMITTED_KHR
Sourceimpl Result
Generated from ‘VK_KHR_global_priority’
impl Result
Generated from ‘VK_KHR_global_priority’
pub const ERROR_NOT_PERMITTED_KHR: Result
Sourceimpl Result
Generated from ‘VK_EXT_buffer_device_address’
impl Result
Generated from ‘VK_EXT_buffer_device_address’
pub const ERROR_INVALID_DEVICE_ADDRESS_EXT: Result = Self::ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS
Sourceimpl Result
Generated from ‘VK_KHR_buffer_device_address’
impl Result
Generated from ‘VK_KHR_buffer_device_address’
pub const ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS_KHR: Result = Self::ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS
Sourceimpl Result
Generated from ‘VK_KHR_deferred_host_operations’
impl Result
Generated from ‘VK_KHR_deferred_host_operations’
pub const THREAD_IDLE_KHR: Result
pub const THREAD_DONE_KHR: Result
pub const OPERATION_DEFERRED_KHR: Result
pub const OPERATION_NOT_DEFERRED_KHR: Result
Sourceimpl Result
Generated from ‘VK_EXT_pipeline_creation_cache_control’
impl Result
Generated from ‘VK_EXT_pipeline_creation_cache_control’
pub const PIPELINE_COMPILE_REQUIRED_EXT: Result = Self::PIPELINE_COMPILE_REQUIRED
pub const ERROR_PIPELINE_COMPILE_REQUIRED_EXT: Result = Self::PIPELINE_COMPILE_REQUIRED
Sourceimpl Result
Generated from ‘VK_EXT_image_compression_control’
impl Result
Generated from ‘VK_EXT_image_compression_control’
pub const ERROR_COMPRESSION_EXHAUSTED_EXT: Result
Sourceimpl Result
Generated from ‘VK_EXT_shader_object’
impl Result
Generated from ‘VK_EXT_shader_object’
pub const ERROR_INCOMPATIBLE_SHADER_BINARY_EXT: Result
Sourceimpl Result
Generated from ‘VK_VERSION_1_1’
impl Result
Generated from ‘VK_VERSION_1_1’
pub const ERROR_OUT_OF_POOL_MEMORY: Result
pub const ERROR_INVALID_EXTERNAL_HANDLE: Result
Sourceimpl Result
Generated from ‘VK_VERSION_1_2’
impl Result
Generated from ‘VK_VERSION_1_2’
pub const ERROR_FRAGMENTATION: Result
pub const ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS: Result