pub enum AllocationScheme {
DedicatedBuffer(Buffer),
DedicatedImage(Image),
GpuAllocatorManaged,
}Variants
DedicatedBuffer(Buffer)
Perform a dedicated, driver-managed allocation for the given buffer, allowing it to perform optimizations on this type of allocation.
DedicatedImage(Image)
Perform a dedicated, driver-managed allocation for the given image, allowing it to perform optimizations on this type of allocation.
GpuAllocatorManaged
The memory for this resource will be allocated and managed by gpu-allocator.