Module resource_ref_map

Module resource_ref_map 

Structs

ResourceRef
ResourceRefBorrow
ResourceRefBorrowMut
ResourceRefMap
Like ResourceMap, but the insertions are temporary. This is an alternative to making a large amount of code generic just to pass down an arbitrary