pub struct ZoneHandle(/* private fields */);Trait Implementations
Sourceimpl Clone for ZoneHandle
impl Clone for ZoneHandle
Sourcefn clone(&self) -> ZoneHandle
fn clone(&self) -> ZoneHandle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ZoneHandle
impl Debug for ZoneHandle
Sourceimpl Default for ZoneHandle
impl Default for ZoneHandle
Sourcefn default() -> ZoneHandle
fn default() -> ZoneHandle
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for ZoneHandle
impl From<KeyData> for ZoneHandle
Sourcefn from(k: KeyData) -> ZoneHandle
fn from(k: KeyData) -> ZoneHandle
Converts to this type from the input type.
Sourceimpl Hash for ZoneHandle
impl Hash for ZoneHandle
Sourceimpl Key for ZoneHandle
impl Key for ZoneHandle
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ZoneHandle
impl Ord for ZoneHandle
Sourcefn cmp(&self, other: &ZoneHandle) -> Ordering
fn cmp(&self, other: &ZoneHandle) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ZoneHandle
impl PartialEq for ZoneHandle
Sourceimpl PartialOrd for ZoneHandle
impl PartialOrd for ZoneHandle
impl Copy for ZoneHandle
impl Eq for ZoneHandle
impl StructuralPartialEq for ZoneHandle