pub struct SubmitNodeBlock<SubmitPacketDataT>where
SubmitPacketDataT: SubmitPacketData,{ /* private fields */ }Expand description
The SubmitNodeBlock is a collection of SubmitNode associated with a particular RenderFeature,
RenderView, and RenderPhase. There should be a 1:1 mapping between SubmitNodes and draw calls
from the RenderFeature’s WriteJob. The Renderer will combine all SubmitNodeBlocks sharing the
same RenderView and RenderPhase into a sorted ViewPhaseSubmitNodeBlock.
Implementations
Sourceimpl<SubmitPacketDataT> SubmitNodeBlock<SubmitPacketDataT>
impl<SubmitPacketDataT> SubmitNodeBlock<SubmitPacketDataT>
pub fn len(&self) -> usize
Sourcepub fn with_capacity<RenderPhaseT>(
view: &RenderView,
num_submit_nodes: usize,
) -> SubmitNodeBlock<SubmitPacketDataT>where
RenderPhaseT: RenderPhase,
pub fn with_capacity<RenderPhaseT>(
view: &RenderView,
num_submit_nodes: usize,
) -> SubmitNodeBlock<SubmitPacketDataT>where
RenderPhaseT: RenderPhase,
Creates a SubmitNodeBlock with a capacity of num_submit_nodes if the RenderView
supports the RenderPhase, otherwise the capacity will be set to 0.
Sourcepub fn with_capacity_and_feature_flag<RenderPhaseT, RenderFeatureFlagT>(
view: &RenderView,
num_submit_nodes: usize,
) -> SubmitNodeBlock<SubmitPacketDataT>where
RenderPhaseT: RenderPhase,
RenderFeatureFlagT: RenderFeatureFlag,
pub fn with_capacity_and_feature_flag<RenderPhaseT, RenderFeatureFlagT>(
view: &RenderView,
num_submit_nodes: usize,
) -> SubmitNodeBlock<SubmitPacketDataT>where
RenderPhaseT: RenderPhase,
RenderFeatureFlagT: RenderFeatureFlag,
Creates a SubmitNodeBlock with a capacity of num_submit_nodes if the RenderView
supports the RenderPhase and RenderFeatureFlag, otherwise the capacity will be set to 0.
pub fn push_submit_node( &self, data: <SubmitPacketDataT as SubmitPacketData>::SubmitNodeData, sort_key: u32, distance: f32, ) -> u32
pub fn get_submit_node_data( &self, index: u32, ) -> &SubmitNode<<SubmitPacketDataT as SubmitPacketData>::SubmitNodeData>
pub fn is_relevant(&self, render_phase: u32) -> bool